// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: protobuf-c/protobuf-c.proto
// Protobuf C++ Version: 7.35.0

#include "protobuf-c/protobuf-c.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::ProtobufCFileOptions
        {&::_pbi::kDescriptorMethods, &::descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto, /* tracker*/ nullptr,},
        // ::ProtobufCMessageOptions
        {&::_pbi::kDescriptorMethods, &::descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto, /* tracker*/ nullptr,},
        // ::ProtobufCFieldOptions
        {&::_pbi::kDescriptorMethods, &::descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
class ProtobufCMessageOptions::_Internal {
 public:
  using HasBits = decltype(::std::declval<ProtobufCMessageOptions>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_._has_bits_);
};

constexpr ProtobufCMessageOptions::ParseTableT_ ProtobufCMessageOptions::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::ProtobufCMessageOptions>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // optional bool gen_pack_helpers = 1 [default = false];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCMessageOptions, _impl_.gen_pack_helpers_), 1>(),
       {8, 1, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_pack_helpers_)}},
      // optional bool gen_init_helpers = 2 [default = true];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCMessageOptions, _impl_.gen_init_helpers_), 2>(),
       {16, 2, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_init_helpers_)}},
      // optional string base_field_name = 3 [default = "base"];
      {::_pbi::TcParser::FastBS1,
       {26, 0, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.base_field_name_)}},
    }}, {{
      65535, 65535
    }}, {{
      // optional bool gen_pack_helpers = 1 [default = false];
      {PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_pack_helpers_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional bool gen_init_helpers = 2 [default = true];
      {PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_init_helpers_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional string base_field_name = 3 [default = "base"];
      {PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.base_field_name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr ProtobufCMessageOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        base_field_name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        gen_pack_helpers_{false},
        gen_init_helpers_{true} {}

template <typename>
constexpr ProtobufCMessageOptions::ProtobufCMessageOptions(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ProtobufCMessageOptions::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ProtobufCMessageOptions(arena);
}
constexpr auto ProtobufCMessageOptions::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ProtobufCMessageOptions), alignof(ProtobufCMessageOptions));
}
constexpr auto ProtobufCMessageOptions::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ProtobufCMessageOptions::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ProtobufCMessageOptions>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ProtobufCMessageOptions::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ProtobufCMessageOptions>(), &ProtobufCMessageOptions::ByteSizeLong,
              &ProtobufCMessageOptions::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ProtobufCMessageOptionsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ProtobufCMessageOptionsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ProtobufCMessageOptions_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ProtobufCMessageOptions::InternalGenerateClassData_(
            _default, &ProtobufCMessageOptions_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ProtobufCMessageOptions>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ProtobufCMessageOptionsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ProtobufCMessageOptions _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ProtobufCMessageOptions>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptionsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ProtobufCMessageOptionsGlobalsTypeInternal ProtobufCMessageOptions_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ProtobufCMessageOptions_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ProtobufCMessageOptions_globals_.GetClassData();
#else
  return ProtobufCMessageOptions_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ProtobufCFileOptions::_Internal {
 public:
  using HasBits = decltype(::std::declval<ProtobufCFileOptions>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_._has_bits_);
};

constexpr ProtobufCFileOptions::ParseTableT_ ProtobufCFileOptions::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_._has_bits_),
      0, // no _extensions_
      6, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967232,  // skipmap
      offsetof(ParseTableT_, field_entries),
      6,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::ProtobufCFileOptions>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // optional bool no_generate = 1 [default = false];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.no_generate_), 1>(),
       {8, 1, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.no_generate_)}},
      // optional bool gen_pack_helpers = 2 [default = true];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.gen_pack_helpers_), 4>(),
       {16, 4, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_pack_helpers_)}},
      // optional bool gen_init_helpers = 3 [default = true];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.gen_init_helpers_), 5>(),
       {24, 5, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_init_helpers_)}},
      // optional bool const_strings = 4 [default = false];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.const_strings_), 2>(),
       {32, 2, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.const_strings_)}},
      // optional bool use_oneof_field_name = 5 [default = false];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.use_oneof_field_name_), 3>(),
       {40, 3, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.use_oneof_field_name_)}},
      // optional string c_package = 6;
      {::_pbi::TcParser::FastBS1,
       {50, 0, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.c_package_)}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // optional bool no_generate = 1 [default = false];
      {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.no_generate_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional bool gen_pack_helpers = 2 [default = true];
      {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_pack_helpers_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional bool gen_init_helpers = 3 [default = true];
      {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_init_helpers_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional bool const_strings = 4 [default = false];
      {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.const_strings_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional bool use_oneof_field_name = 5 [default = false];
      {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.use_oneof_field_name_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional string c_package = 6;
      {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.c_package_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr ProtobufCFileOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        c_package_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        no_generate_{false},
        const_strings_{false},
        use_oneof_field_name_{false},
        gen_pack_helpers_{true},
        gen_init_helpers_{true} {}

template <typename>
constexpr ProtobufCFileOptions::ProtobufCFileOptions(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ProtobufCFileOptions::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ProtobufCFileOptions(arena);
}
constexpr auto ProtobufCFileOptions::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ProtobufCFileOptions), alignof(ProtobufCFileOptions));
}
constexpr auto ProtobufCFileOptions::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ProtobufCFileOptions::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ProtobufCFileOptions>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ProtobufCFileOptions::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ProtobufCFileOptions>(), &ProtobufCFileOptions::ByteSizeLong,
              &ProtobufCFileOptions::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ProtobufCFileOptionsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ProtobufCFileOptionsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ProtobufCFileOptions_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ProtobufCFileOptions::InternalGenerateClassData_(
            _default, &ProtobufCFileOptions_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ProtobufCFileOptions>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ProtobufCFileOptionsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ProtobufCFileOptions _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ProtobufCFileOptions>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ProtobufCFileOptionsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ProtobufCFileOptionsGlobalsTypeInternal ProtobufCFileOptions_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ProtobufCFileOptions_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ProtobufCFileOptions_globals_.GetClassData();
#else
  return ProtobufCFileOptions_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ProtobufCFieldOptions::_Internal {
 public:
  using HasBits = decltype(::std::declval<ProtobufCFieldOptions>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_._has_bits_);
};

constexpr ProtobufCFieldOptions::ParseTableT_ ProtobufCFieldOptions::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::ProtobufCFieldOptions>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // optional bool string_as_bytes = 1 [default = false];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFieldOptions, _impl_.string_as_bytes_), 0>(),
       {8, 0, 0,
        PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_.string_as_bytes_)}},
    }}, {{
      65535, 65535
    }}, {{
      // optional bool string_as_bytes = 1 [default = false];
      {PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_.string_as_bytes_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr ProtobufCFieldOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        string_as_bytes_{false} {}

template <typename>
constexpr ProtobufCFieldOptions::ProtobufCFieldOptions(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ProtobufCFieldOptions::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ProtobufCFieldOptions(arena);
}
constexpr auto ProtobufCFieldOptions::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(ProtobufCFieldOptions), alignof(ProtobufCFieldOptions));
}
constexpr auto ProtobufCFieldOptions::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ProtobufCFieldOptions::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ProtobufCFieldOptions>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ProtobufCFieldOptions::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ProtobufCFieldOptions>(), &ProtobufCFieldOptions::ByteSizeLong,
              &ProtobufCFieldOptions::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ProtobufCFieldOptionsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ProtobufCFieldOptionsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ProtobufCFieldOptions_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ProtobufCFieldOptions::InternalGenerateClassData_(
            _default, &ProtobufCFieldOptions_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ProtobufCFieldOptions>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ProtobufCFieldOptionsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ProtobufCFieldOptions _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ProtobufCFieldOptions>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptionsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ProtobufCFieldOptionsGlobalsTypeInternal ProtobufCFieldOptions_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ProtobufCFieldOptions_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ProtobufCFieldOptions_globals_.GetClassData();
#else
  return ProtobufCFieldOptions_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
static constexpr const ::_pb::EnumDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_enum_descriptors_protobuf_2dc_2fprotobuf_2dc_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_protobuf_2dc_2fprotobuf_2dc_2eproto = nullptr;
const ::uint32_t
    TableStruct_protobuf_2dc_2fprotobuf_2dc_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.no_generate_),
        PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.gen_pack_helpers_),
        PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.gen_init_helpers_),
        PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.const_strings_),
        PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.use_oneof_field_name_),
        PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.c_package_),
        1,
        4,
        5,
        2,
        3,
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _impl_.gen_pack_helpers_),
        PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _impl_.gen_init_helpers_),
        PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _impl_.base_field_name_),
        1,
        2,
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::ProtobufCFieldOptions, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::ProtobufCFieldOptions, _impl_.string_as_bytes_),
        0,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::ProtobufCFileOptions)},
        {15, sizeof(::ProtobufCMessageOptions)},
        {24, sizeof(::ProtobufCFieldOptions)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::ProtobufCFileOptions_globals_,
        &::ProtobufCMessageOptions_globals_,
        &::ProtobufCFieldOptions_globals_,
};
const char descriptor_table_protodef_protobuf_2dc_2fprotobuf_2dc_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\033protobuf-c/protobuf-c.proto\032 google/pr"
    "otobuf/descriptor.proto\"\310\001\n\024ProtobufCFil"
    "eOptions\022\032\n\013no_generate\030\001 \001(\010:\005false\022\036\n\020"
    "gen_pack_helpers\030\002 \001(\010:\004true\022\036\n\020gen_init"
    "_helpers\030\003 \001(\010:\004true\022\034\n\rconst_strings\030\004 "
    "\001(\010:\005false\022#\n\024use_oneof_field_name\030\005 \001(\010"
    ":\005false\022\021\n\tc_package\030\006 \001(\t\"y\n\027ProtobufCM"
    "essageOptions\022\037\n\020gen_pack_helpers\030\001 \001(\010:"
    "\005false\022\036\n\020gen_init_helpers\030\002 \001(\010:\004true\022\035"
    "\n\017base_field_name\030\003 \001(\t:\004base\"7\n\025Protobu"
    "fCFieldOptions\022\036\n\017string_as_bytes\030\001 \001(\010:"
    "\005false:G\n\tpb_c_file\022\034.google.protobuf.Fi"
    "leOptions\030\373\007 \001(\0132\025.ProtobufCFileOptions:"
    "L\n\010pb_c_msg\022\037.google.protobuf.MessageOpt"
    "ions\030\373\007 \001(\0132\030.ProtobufCMessageOptions:J\n"
    "\npb_c_field\022\035.google.protobuf.FieldOptio"
    "ns\030\373\007 \001(\0132\026.ProtobufCFieldOptionsB\005\332\?\002\010\001"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_deps[1] = {
        &::descriptor_table_google_2fprotobuf_2fdescriptor_2eproto,
};
static ::absl::once_flag descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto = {
    false,
    false,
    680,
    descriptor_table_protodef_protobuf_2dc_2fprotobuf_2dc_2eproto,
    "protobuf-c/protobuf-c.proto",
    &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_once,
    descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_deps,
    1,
    3,
    schemas,
    file_message_globals,
    TableStruct_protobuf_2dc_2fprotobuf_2dc_2eproto::offsets,
    file_level_enum_descriptors_protobuf_2dc_2fprotobuf_2dc_2eproto,
    file_level_service_descriptors_protobuf_2dc_2fprotobuf_2dc_2eproto,
};
// ===================================================================

ProtobufCFileOptions::ProtobufCFileOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtobufCFileOptions_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:ProtobufCFileOptions)
}
PROTOBUF_NDEBUG_INLINE ProtobufCFileOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::ProtobufCFileOptions& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        c_package_(arena, from.c_package_) {}

ProtobufCFileOptions::ProtobufCFileOptions(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ProtobufCFileOptions& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtobufCFileOptions_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ProtobufCFileOptions* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, no_generate_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, no_generate_),
           offsetof(Impl_, gen_init_helpers_) -
               offsetof(Impl_, no_generate_) +
               sizeof(Impl_::gen_init_helpers_));

  // @@protoc_insertion_point(copy_constructor:ProtobufCFileOptions)
}
PROTOBUF_NDEBUG_INLINE ProtobufCFileOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        c_package_(arena),
        gen_pack_helpers_{true},
        gen_init_helpers_{true} {}

inline void ProtobufCFileOptions::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, no_generate_),
           0,
           offsetof(Impl_, use_oneof_field_name_) -
               offsetof(Impl_, no_generate_) +
               sizeof(Impl_::use_oneof_field_name_));
}
ProtobufCFileOptions::~ProtobufCFileOptions() {
  // @@protoc_insertion_point(destructor:ProtobufCFileOptions)
  SharedDtor(*this);
}
inline void ProtobufCFileOptions::SharedDtor(MessageLite& self) {
  ProtobufCFileOptions& this_ = static_cast<ProtobufCFileOptions&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.c_package_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ProtobufCFileOptions_class_data_ =
        ProtobufCFileOptions::InternalGenerateClassData_(ProtobufCFileOptions_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtobufCFileOptions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtobufCFileOptions_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ProtobufCFileOptions_class_data_.tc_table);
  return ProtobufCFileOptions_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtobufCFileOptions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtobufCFileOptions_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ProtobufCFileOptions_globals_));
  return ProtobufCFileOptions_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ProtobufCFileOptions::ParseTableT_
    ProtobufCFileOptions::_table_ =
        ProtobufCFileOptions::InternalGenerateParseTable_(ProtobufCFileOptions_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ProtobufCFileOptions::Clear() {
// @@protoc_insertion_point(message_clear_start:ProtobufCFileOptions)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.c_package_.ClearNonDefaultToEmpty();
  }
  ::memset(&_impl_.no_generate_, 0, static_cast<::size_t>(
      reinterpret_cast<char*>(&_impl_.use_oneof_field_name_) -
      reinterpret_cast<char*>(&_impl_.no_generate_)) + sizeof(_impl_.use_oneof_field_name_));
  if (BatchCheckHasBit(cached_has_bits, 0x00000030U)) {
    _impl_.gen_pack_helpers_ = true;
    _impl_.gen_init_helpers_ = true;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ProtobufCFileOptions::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ProtobufCFileOptions& this_ = static_cast<const ProtobufCFileOptions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ProtobufCFileOptions::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ProtobufCFileOptions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:ProtobufCFileOptions)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // optional bool no_generate = 1 [default = false];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        1, this_._internal_no_generate(), target);
  }

  // optional bool gen_pack_helpers = 2 [default = true];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        2, this_._internal_gen_pack_helpers(), target);
  }

  // optional bool gen_init_helpers = 3 [default = true];
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        3, this_._internal_gen_init_helpers(), target);
  }

  // optional bool const_strings = 4 [default = false];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        4, this_._internal_const_strings(), target);
  }

  // optional bool use_oneof_field_name = 5 [default = false];
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        5, this_._internal_use_oneof_field_name(), target);
  }

  // optional string c_package = 6;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    const ::std::string& _s = this_._internal_c_package();
    target = stream->WriteStringMaybeAliased(6, _s, target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ProtobufCFileOptions)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ProtobufCFileOptions::ByteSizeLong(const MessageLite& base) {
  const ProtobufCFileOptions& this_ = static_cast<const ProtobufCFileOptions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ProtobufCFileOptions::ByteSizeLong() const {
  const ProtobufCFileOptions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:ProtobufCFileOptions)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  total_size += ::absl::popcount(0x0000003eU & cached_has_bits) * 2;
   {
    // optional string c_package = 6;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_c_package());
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ProtobufCFileOptions::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ProtobufCFileOptions*>(&to_msg);
  auto& from = static_cast<const ProtobufCFileOptions&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:ProtobufCFileOptions)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_set_c_package(from._internal_c_package());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_impl_.no_generate_ = from._impl_.no_generate_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_impl_.const_strings_ = from._impl_.const_strings_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_impl_.use_oneof_field_name_ = from._impl_.use_oneof_field_name_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_impl_.gen_pack_helpers_ = from._impl_.gen_pack_helpers_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _this->_impl_.gen_init_helpers_ = from._impl_.gen_init_helpers_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ProtobufCFileOptions::CopyFrom(const ProtobufCFileOptions& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:ProtobufCFileOptions)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ProtobufCFileOptions::InternalSwap(ProtobufCFileOptions* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.c_package_, &other->_impl_.c_package_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_init_helpers_)
      + sizeof(ProtobufCFileOptions::_impl_.gen_init_helpers_)
      - PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.no_generate_)>(
          reinterpret_cast<char*>(&_impl_.no_generate_),
          reinterpret_cast<char*>(&other->_impl_.no_generate_));
}

::google::protobuf::Metadata ProtobufCFileOptions::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

/*static*/ const ::_pbi::LazyString ProtobufCMessageOptions::Impl_::_i_give_permission_to_break_this_code_default_base_field_name_{
    {{"base", 4}},
    {nullptr},
};
ProtobufCMessageOptions::ProtobufCMessageOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtobufCMessageOptions_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:ProtobufCMessageOptions)
}
PROTOBUF_NDEBUG_INLINE ProtobufCMessageOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::ProtobufCMessageOptions& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        base_field_name_(arena, from.base_field_name_, _i_give_permission_to_break_this_code_default_base_field_name_) {}

ProtobufCMessageOptions::ProtobufCMessageOptions(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ProtobufCMessageOptions& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtobufCMessageOptions_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ProtobufCMessageOptions* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, gen_pack_helpers_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, gen_pack_helpers_),
           offsetof(Impl_, gen_init_helpers_) -
               offsetof(Impl_, gen_pack_helpers_) +
               sizeof(Impl_::gen_init_helpers_));

  // @@protoc_insertion_point(copy_constructor:ProtobufCMessageOptions)
}
PROTOBUF_NDEBUG_INLINE ProtobufCMessageOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        base_field_name_(arena, Impl_::_i_give_permission_to_break_this_code_default_base_field_name_),
        gen_init_helpers_{true} {}

inline void ProtobufCMessageOptions::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.gen_pack_helpers_ = {};
}
ProtobufCMessageOptions::~ProtobufCMessageOptions() {
  // @@protoc_insertion_point(destructor:ProtobufCMessageOptions)
  SharedDtor(*this);
}
inline void ProtobufCMessageOptions::SharedDtor(MessageLite& self) {
  ProtobufCMessageOptions& this_ = static_cast<ProtobufCMessageOptions&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.base_field_name_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ProtobufCMessageOptions_class_data_ =
        ProtobufCMessageOptions::InternalGenerateClassData_(ProtobufCMessageOptions_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtobufCMessageOptions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtobufCMessageOptions_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ProtobufCMessageOptions_class_data_.tc_table);
  return ProtobufCMessageOptions_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtobufCMessageOptions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtobufCMessageOptions_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ProtobufCMessageOptions_globals_));
  return ProtobufCMessageOptions_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ProtobufCMessageOptions::ParseTableT_
    ProtobufCMessageOptions::_table_ =
        ProtobufCMessageOptions::InternalGenerateParseTable_(ProtobufCMessageOptions_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ProtobufCMessageOptions::Clear() {
// @@protoc_insertion_point(message_clear_start:ProtobufCMessageOptions)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.base_field_name_.ClearToDefault(::ProtobufCMessageOptions::Impl_::_i_give_permission_to_break_this_code_default_base_field_name_, GetArena());
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000006U)) {
    _impl_.gen_pack_helpers_ = false;
    _impl_.gen_init_helpers_ = true;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ProtobufCMessageOptions::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ProtobufCMessageOptions& this_ = static_cast<const ProtobufCMessageOptions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ProtobufCMessageOptions::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ProtobufCMessageOptions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:ProtobufCMessageOptions)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // optional bool gen_pack_helpers = 1 [default = false];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        1, this_._internal_gen_pack_helpers(), target);
  }

  // optional bool gen_init_helpers = 2 [default = true];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        2, this_._internal_gen_init_helpers(), target);
  }

  // optional string base_field_name = 3 [default = "base"];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    const ::std::string& _s = this_._internal_base_field_name();
    target = stream->WriteStringMaybeAliased(3, _s, target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ProtobufCMessageOptions)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ProtobufCMessageOptions::ByteSizeLong(const MessageLite& base) {
  const ProtobufCMessageOptions& this_ = static_cast<const ProtobufCMessageOptions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ProtobufCMessageOptions::ByteSizeLong() const {
  const ProtobufCMessageOptions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:ProtobufCMessageOptions)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  total_size += ::absl::popcount(0x00000006U & cached_has_bits) * 2;
   {
    // optional string base_field_name = 3 [default = "base"];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_base_field_name());
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ProtobufCMessageOptions::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ProtobufCMessageOptions*>(&to_msg);
  auto& from = static_cast<const ProtobufCMessageOptions&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:ProtobufCMessageOptions)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_set_base_field_name(from._internal_base_field_name());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_impl_.gen_pack_helpers_ = from._impl_.gen_pack_helpers_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_impl_.gen_init_helpers_ = from._impl_.gen_init_helpers_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ProtobufCMessageOptions::CopyFrom(const ProtobufCMessageOptions& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:ProtobufCMessageOptions)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ProtobufCMessageOptions::InternalSwap(ProtobufCMessageOptions* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.base_field_name_, &other->_impl_.base_field_name_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_init_helpers_)
      + sizeof(ProtobufCMessageOptions::_impl_.gen_init_helpers_)
      - PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_pack_helpers_)>(
          reinterpret_cast<char*>(&_impl_.gen_pack_helpers_),
          reinterpret_cast<char*>(&other->_impl_.gen_pack_helpers_));
}

::google::protobuf::Metadata ProtobufCMessageOptions::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

ProtobufCFieldOptions::ProtobufCFieldOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtobufCFieldOptions_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:ProtobufCFieldOptions)
}
ProtobufCFieldOptions::ProtobufCFieldOptions(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ProtobufCFieldOptions& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtobufCFieldOptions_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE ProtobufCFieldOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void ProtobufCFieldOptions::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.string_as_bytes_ = {};
}
ProtobufCFieldOptions::~ProtobufCFieldOptions() {
  // @@protoc_insertion_point(destructor:ProtobufCFieldOptions)
  SharedDtor(*this);
}
inline void ProtobufCFieldOptions::SharedDtor(MessageLite& self) {
  ProtobufCFieldOptions& this_ = static_cast<ProtobufCFieldOptions&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ProtobufCFieldOptions_class_data_ =
        ProtobufCFieldOptions::InternalGenerateClassData_(ProtobufCFieldOptions_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtobufCFieldOptions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtobufCFieldOptions_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ProtobufCFieldOptions_class_data_.tc_table);
  return ProtobufCFieldOptions_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtobufCFieldOptions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtobufCFieldOptions_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ProtobufCFieldOptions_globals_));
  return ProtobufCFieldOptions_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ProtobufCFieldOptions::ParseTableT_
    ProtobufCFieldOptions::_table_ =
        ProtobufCFieldOptions::InternalGenerateParseTable_(ProtobufCFieldOptions_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ProtobufCFieldOptions::Clear() {
// @@protoc_insertion_point(message_clear_start:ProtobufCFieldOptions)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.string_as_bytes_ = false;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ProtobufCFieldOptions::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ProtobufCFieldOptions& this_ = static_cast<const ProtobufCFieldOptions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ProtobufCFieldOptions::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ProtobufCFieldOptions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:ProtobufCFieldOptions)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // optional bool string_as_bytes = 1 [default = false];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        1, this_._internal_string_as_bytes(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ProtobufCFieldOptions)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ProtobufCFieldOptions::ByteSizeLong(const MessageLite& base) {
  const ProtobufCFieldOptions& this_ = static_cast<const ProtobufCFieldOptions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ProtobufCFieldOptions::ByteSizeLong() const {
  const ProtobufCFieldOptions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:ProtobufCFieldOptions)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  total_size += static_cast<bool>(0x00000001U & cached_has_bits) * 2;
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ProtobufCFieldOptions::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ProtobufCFieldOptions*>(&to_msg);
  auto& from = static_cast<const ProtobufCFieldOptions&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:ProtobufCFieldOptions)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_impl_.string_as_bytes_ = from._impl_.string_as_bytes_;
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ProtobufCFieldOptions::CopyFrom(const ProtobufCFieldOptions& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:ProtobufCFieldOptions)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ProtobufCFieldOptions::InternalSwap(ProtobufCFieldOptions* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.string_as_bytes_, other->_impl_.string_as_bytes_);
}

::google::protobuf::Metadata ProtobufCFieldOptions::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 ::_pbi::ExtensionIdentifier<
        ::google::protobuf::FileOptions, ::_pbi::MessageTypeTraits< ::ProtobufCFileOptions >, 11, false>
        pb_c_file(kPbCFileFieldNumber, &::ProtobufCFileOptions_globals_);
PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 ::_pbi::ExtensionIdentifier<
        ::google::protobuf::MessageOptions, ::_pbi::MessageTypeTraits< ::ProtobufCMessageOptions >, 11, false>
        pb_c_msg(kPbCMsgFieldNumber, &::ProtobufCMessageOptions_globals_);
PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 ::_pbi::ExtensionIdentifier<
        ::google::protobuf::FieldOptions, ::_pbi::MessageTypeTraits< ::ProtobufCFieldOptions >, 11, false>
        pb_c_field(kPbCFieldFieldNumber, &::ProtobufCFieldOptions_globals_);
// @@protoc_insertion_point(namespace_scope)
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto),
        ::_pbi::ExtensionSet::RegisterMessageExtension(
            &::google::protobuf::FileOptions::default_instance(), 1019, 11,
            false, false, &::ProtobufCFileOptions::default_instance(),
            nullptr, ::_pbi::LazyAnnotation::kUndefined),
        ::_pbi::ExtensionSet::RegisterMessageExtension(
            &::google::protobuf::MessageOptions::default_instance(), 1019, 11,
            false, false, &::ProtobufCMessageOptions::default_instance(),
            nullptr, ::_pbi::LazyAnnotation::kUndefined),
        ::_pbi::ExtensionSet::RegisterMessageExtension(
            &::google::protobuf::FieldOptions::default_instance(), 1019, 11,
            false, false, &::ProtobufCFieldOptions::default_instance(),
            nullptr, ::_pbi::LazyAnnotation::kUndefined),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
